==> physx-jni-0.4.0-sources.jar: physx/cooking/PxBVH34MidphaseDesc.java <==
package physx.cooking;

import physx.NativeObject;

public class PxBVH34MidphaseDesc extends NativeObject {

    protected PxBVH34MidphaseDesc() { }

    public static PxBVH34MidphaseDesc wrapPointer(long address) {
        return new PxBVH34MidphaseDesc(address);
    }
    
    protected PxBVH34MidphaseDesc(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNumPrimsPerLeaf() {
        return _getNumPrimsPerLeaf(address);
    }
    private static native int _getNumPrimsPerLeaf(long address);

    /**
     * @param value WebIDL type: unsigned long
     */
    public void setNumPrimsPerLeaf(int value) {
        _setNumPrimsPerLeaf(address, value);
    }
    private static native void _setNumPrimsPerLeaf(long address, int value);

    // Functions

    public void setToDefault() {
        _setToDefault(address);
    }
    private static native void _setToDefault(long address);

    /**
     * @return WebIDL type: boolean
     */
    public boolean isValid() {
        return _isValid(address);
    }
    private static native boolean _isValid(long address);

}

==> physx-jni-0.4.1-sources.jar: physx/cooking/PxBVH34MidphaseDesc.java <==
package physx.cooking;

import physx.NativeObject;

public class PxBVH34MidphaseDesc extends NativeObject {

    protected PxBVH34MidphaseDesc() { }

    public static PxBVH34MidphaseDesc wrapPointer(long address) {
        return address != 0L ? new PxBVH34MidphaseDesc(address) : null;
    }
    
    protected PxBVH34MidphaseDesc(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNumPrimsPerLeaf() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getNumPrimsPerLeaf(address);
    }
    private static native int _getNumPrimsPerLeaf(long address);

    /**
     * @param value WebIDL type: unsigned long
     */
    public void setNumPrimsPerLeaf(int value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setNumPrimsPerLeaf(address, value);
    }
    private static native void _setNumPrimsPerLeaf(long address, int value);

    // Functions

    public void setToDefault() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setToDefault(address);
    }
    private static native void _setToDefault(long address);

    /**
     * @return WebIDL type: boolean
     */
    public boolean isValid() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _isValid(address);
    }
    private static native boolean _isValid(long address);

}
